@@ -50,8 +50,10 @@ def init_interface(self, stdscr) -> bool:
     # Hide cursor
     curses.curs_set(0)
     # Colors
-    curses.init_pair(1, curses.COLOR_WHITE, curses.COLOR_BLACK)
-    stdscr.bkgd(" ", curses.color_pair(1) | curses.A_BOLD)
+    curses.start_color()
+    curses.use_default_colors()
+    for i in range(0, 255):
+        curses.init_pair(i + 1, i, -1)
 
     self.screen = stdscr
     self.screen.clear()
@@ -79,12 +81,10 @@ def refresh_interface(self):
     # Process timing
     run_time = format_time_elapsed(self.fuzz_start_time).ljust(32)
     last_new_path_time = format_time_elapsed(self.last_new_path_time).ljust(32)
-    last_unique_crash_time = format_time_elapsed(
-        self.last_unique_crash_time
-    ).ljust(32)
-    last_unique_timeout_time = format_time_elapsed(
-        self.last_unique_timeout_time
-    ).ljust(32)
+    last_unique_crash_time = format_time_elapsed(self.last_unique_crash_time).ljust(32)
+    last_unique_timeout_time = format_time_elapsed(self.last_unique_timeout_time).ljust(
+        32
+    )
 
     # Overall results
     uniques_crashes_count = str(self.unique_crashes).ljust(9)
@@ -172,9 +172,7 @@ def exit_message(
     run_time = format_time_elapsed(self.fuzz_start_time)
     uniques_crashes_count = str(self.unique_crashes)
     uniques_timeouts_count = str(self.unique_timeout)
-    total_timeouts = "{total_timeouts}".format(
-        total_timeouts=self.total_timeouts
-    )
+    total_timeouts = "{total_timeouts}".format(total_timeouts=self.total_timeouts)
     total_paths_count = str(len(self.reached_instructions))
     cycles_count = str(self.cycles_count)
     total_executions = str(self.inputs_count)
@@ -248,6 +246,13 @@ def start_interface(self) -> None:
     Display the curse interface
     """
     wrapper(self.init_interface)
-    while True:
+    while self.alive:
         self.refresh_interface()
         time.sleep(REFRESH_INTERVAL)
+
+
+def kill_interface(self) -> None:
+    """
+    Kill the current curses window
+    """
+    curses.endwin()
