@@ -14,9 +14,7 @@ class Config:
 
     # Enable the use of mutations based on dictionary elements
     if os.getenv("FRELATAGE_DICTIONARY_ENABLE", "1") not in ("1", "0"):
-        raise FrelatageConfigError(
-            "FRELATAGE_DICTIONARY_ENABLE must '1' or '0'"
-        )
+        raise FrelatageConfigError("FRELATAGE_DICTIONARY_ENABLE must '1' or '0'")
     FRELATAGE_DICTIONARY_ENABLE = (
         True if os.getenv("FRELATAGE_DICTIONARY_ENABLE", "1") == "1" else False
     )
@@ -29,11 +27,9 @@ class Config:
     )
 
     # Delay in seconds after which a function will return a timeoutError
-    # Must be in range 1~20
+    # Must be greater than 1
     if not 1 <= int(os.getenv("FRELATAGE_TIMEOUT_DELAY", 2)) <= math.inf:
-        raise FrelatageConfigError(
-            "FRELATAGE_TIMEOUT_DELAY must be in range 1~20"
-        )
+        raise FrelatageConfigError("FRELATAGE_TIMEOUT_DELAY must be greater than 1")
     FRELATAGE_TIMEOUT_DELAY = int(os.getenv("FRELATAGE_TIMEOUT_DELAY", 2))
 
     # Temporary folder where input files are stored.
@@ -43,23 +39,25 @@ class Config:
     )
 
     # Maximum size of an input variable in bytes
-    # Must be in range 4~1000000
+    # Must be greater than 4
     if not 4 <= int(os.getenv("FRELATAGE_INPUT_MAX_LEN", 1024)) <= math.inf:
-        raise FrelatageConfigError(
-            "FRELATAGE_INPUT_MAX_LEN must be in range 4~1000000"
-        )
+        raise FrelatageConfigError("FRELATAGE_INPUT_MAX_LEN must be greater than 4")
     FRELATAGE_INPUT_MAX_LEN = int(os.getenv("FRELATAGE_INPUT_MAX_LEN", 1024))
 
     # Maximum number of simultaneous threads
-    # Must be in range 8~50
+    # Must be greater than 8
     if not 8 <= int(os.getenv("FRELATAGE_MAX_THREADS", 20)) <= math.inf:
-        raise FrelatageConfigError(
-            "FRELATAGE_MAX_THREADS must be in range 8~50"
-        )
+        raise FrelatageConfigError("FRELATAGE_MAX_THREADS must be greater than 8")
     FRELATAGE_MAX_THREADS = int(os.getenv("FRELATAGE_MAX_THREADS", 20))
 
+    # Maximum number of stages for a fuzzed function
+    # Must be in range greater than 1
+    if not 1 <= int(os.getenv("FRELATAGE_MAX_STAGES", 1000000)) <= math.inf:
+        raise FrelatageConfigError("FRELATAGE_MAX_STAGES must be greater than 1")
+    FRELATAGE_MAX_STAGES = int(os.getenv("FRELATAGE_MAX_STAGES", 1000000))
+
     # Maximum number of successives cycle without a new path
-    # Must be in range 10~50000
+    # Must be greater than 10
     if (
         not 10
         <= int(os.getenv("FRELATAGE_MAX_CYCLES_WITHOUT_NEW_PATHS", 5000))
