@@ -66,12 +66,8 @@ class MutatorStringBitFlip(Mutator):
         if len(input) == 0:
             return input
         position = Mutator.random_int(len(input))
-        replacement_character = chr(
-            ord(input[position]) ^ (1 << Mutator.random_int(8))
-        )
-        mutation = (
-            input[0:position] + replacement_character + input[position + 1 :]
-        )
+        replacement_character = chr(ord(input[position]) ^ (1 << Mutator.random_int(8)))
+        mutation = input[0:position] + replacement_character + input[position + 1 :]
         return mutation
 
 
@@ -87,9 +83,7 @@ class MutatorStringAddSubByte(Mutator):
         position = Mutator.random_int(len(input))
         delta = Mutator.random_int(256)
         replacement_character = chr((ord(input[position]) + delta) % 256)
-        mutation = (
-            input[0:position] + replacement_character + input[position + 1 :]
-        )
+        mutation = input[0:position] + replacement_character + input[position + 1 :]
         return mutation
 
 
@@ -113,9 +107,7 @@ class MutatorStringInsertDict(Mutator):
     allowed_types = set(["str"])
     size_effect = ["increase"]
     # Disable if the dictionary is empty or if the dictionary fuzzing is disabled
-    enabled = (
-        True if (dictionary and Config.FRELATAGE_DICTIONARY_ENABLE) else False
-    )
+    enabled = True if (dictionary and Config.FRELATAGE_DICTIONARY_ENABLE) else False
 
     @staticmethod
     def mutate(input: str) -> str:
@@ -157,10 +149,7 @@ class MutatorStringSwapTwoChars(Mutator):
             second_character_position = Mutator.random_int(len(input))
 
         mutation = list(input)
-        (
-            mutation[first_character_position],
-            mutation[second_character_position],
-        ) = (
+        (mutation[first_character_position], mutation[second_character_position],) = (
             mutation[second_character_position],
             mutation[first_character_position],
         )
@@ -178,15 +167,11 @@ class MutatorStringDuplicateSubString(Mutator):
         if len(input) < 2:
             return input
         first_character_position = Mutator.random_int(len(input))
-        second_character_position = random.randint(
-            first_character_position, len(input)
-        )
+        second_character_position = random.randint(first_character_position, len(input))
         substring = input[first_character_position:second_character_position]
 
         substring_position = Mutator.random_int(len(input))
-        mutation = (
-            input[:substring_position] + substring + input[substring_position:]
-        )
+        mutation = input[:substring_position] + substring + input[substring_position:]
         return mutation
 
 
@@ -200,9 +185,7 @@ class MutatorStringRepeatSubString(Mutator):
         if len(input) < 2:
             return input
         first_character_position = Mutator.random_int(len(input))
-        second_character_position = random.randint(
-            first_character_position, len(input)
-        )
+        second_character_position = random.randint(first_character_position, len(input))
         substring = input[first_character_position:second_character_position]
         mutation = (
             input[:second_character_position]
@@ -222,14 +205,9 @@ class MutatorStringDeleteSubString(Mutator):
         if len(input) < 2:
             return input
         first_character_position = Mutator.random_int(len(input))
-        second_character_position = random.randint(
-            first_character_position, len(input)
-        )
+        second_character_position = random.randint(first_character_position, len(input))
 
-        mutation = (
-            input[:first_character_position]
-            + input[second_character_position:]
-        )
+        mutation = input[:first_character_position] + input[second_character_position:]
         return mutation
 
 
@@ -411,9 +389,7 @@ class MutatorFileFlipBit(Mutator):
                 position = Mutator.random_int(len(file_content))
 
                 mutation = bytearray(file_content)
-                mutation[position] = mutation[position] ^ (
-                    1 << Mutator.random_int(8)
-                )
+                mutation[position] = mutation[position] ^ (1 << Mutator.random_int(8))
                 mutation_bytes = bytes(mutation)
         with open(input, "wb") as f:
             f.write(mutation_bytes)
@@ -484,15 +460,10 @@ class MutatorFileSwapTwoBytes(Mutator):
                 second_byte_position = Mutator.random_int(len(file_content))
                 # The position of the second character must be different from the first
                 while first_byte_position == second_byte_position:
-                    second_byte_position = Mutator.random_int(
-                        len(file_content)
-                    )
+                    second_byte_position = Mutator.random_int(len(file_content))
 
                 mutation = bytearray(file_content)
-                (
-                    mutation[first_byte_position],
-                    mutation[second_byte_position],
-                ) = (
+                (mutation[first_byte_position], mutation[second_byte_position],) = (
                     mutation[second_byte_position],
                     mutation[first_byte_position],
                 )
@@ -523,9 +494,7 @@ class MutatorFileDuplicateSubBytes(Mutator):
                 subbytes = mutation[first_byte_position:second_byte_position]
                 subbytes_position = Mutator.random_int(len(file_content))
                 mutation = (
-                    mutation[:subbytes_position]
-                    + subbytes
-                    + mutation[subbytes_position:]
+                    mutation[:subbytes_position] + subbytes + mutation[subbytes_position:]
                 )
                 mutation_bytes = bytes(mutation)
         with open(input, "wb") as f:
@@ -581,8 +550,7 @@ class MutatorFileDeleteSubBytes(Mutator):
                 )
                 mutation = bytearray(file_content)
                 mutation = (
-                    mutation[:first_byte_position]
-                    + mutation[second_byte_position:]
+                    mutation[:first_byte_position] + mutation[second_byte_position:]
                 )
                 mutation_bytes = bytes(mutation)
         with open(input, "wb") as f:
@@ -595,9 +563,7 @@ class MutatorFileInsertDict(Mutator):
     allowed_types = set(["file"])
     size_effect = ["increase"]
     # Disable if the dictionary is empty or if the dictionary fuzzing is disabled
-    enabled = (
-        True if (dictionary and Config.FRELATAGE_DICTIONARY_ENABLE) else False
-    )
+    enabled = True if (dictionary and Config.FRELATAGE_DICTIONARY_ENABLE) else False
 
     @staticmethod
     def mutate(input: str) -> str:
@@ -611,16 +577,13 @@ class MutatorFileInsertDict(Mutator):
                 mutation = element.encode()
             else:
                 position = Mutator.random_int(len(file_content))
-                mutation = (
-                    mutation[0:position]
-                    + element.encode()
-                    + mutation[position:]
-                )
+                mutation = mutation[0:position] + element.encode() + mutation[position:]
             mutation_bytes = bytes(mutation)
         with open(input, "wb") as f:
             f.write(mutation_bytes)
         return input
 
+
 # Dictionnary mutators
 @register_mutator
 class MutatorDictAddEntry(Mutator):
@@ -631,7 +594,7 @@ class MutatorDictAddEntry(Mutator):
     def mutate(input: dict) -> dict:
         mutation = input
 
-        if random.randint(0,1) == 0:
+        if random.randint(0, 1) == 0:
             integer = random.choice(MagicValues.UINT)
             mutation[integer] = None
         else:
